rpart.Defines the evaluation function for a new splitting method of rpart.
Not to be called directly by the user.
surve(y, wt, parms)the response value as found in the formula that is passed in by rpart.
Note that rpart will normally have removed any observations
with a missing response.
the weight vector from the call, if any.
the vector or list (if any) supplied by the user as a
parms argument to the call.
See reference.
https://cran.r-project.org/package=rpart/vignettes/usercode.pdf