rpart.Defines the initialization function for a new splitting method of rpart.
Not to be called directly by the user.
survi(y, offset, parms, wt)the response value as found in the formula that is passed in by rpart.
Note that rpart will normally
have removed any observations with a missing response.
the offset term, if any, found on the right hand side of the
formula that is passed in by rpart.
the vector or list (if any) supplied by the user as a
parms argument to the call.
the weight vector from the call, if any.
See reference.
https://cran.r-project.org/package=rpart/vignettes/usercode.pdf